@@ -193,6 +193,19 @@ faintly you came tapping, tapping at my chamber door?
 
 MODNAMES = ('clu.compilation.compiledb',
             'clu.compilation.macros',
+            'clu.config',
+            'clu.config.base',
+            'clu.config.env',
+            'clu.config.fieldtypes',
+            'clu.config.filebase',
+            'clu.config.formats',
+            'clu.config.formats.jsonfile',
+            'clu.config.formats.picklefile',
+            'clu.config.formats.tomlfile',
+            'clu.config.formats.yamlfile',
+            'clu.config.settings',
+            'clu.constants.enums',
+            'clu.csv',
             'clu.dicts',
             'clu.enums',
             'clu.exporting',
@@ -207,8 +220,13 @@ MODNAMES = ('clu.compilation.compiledb',
             'clu.repl.ansi',
             'clu.repl.banners',
             'clu.repl.cli',
+            'clu.repl.cli.boilerplate',
             'clu.repl.cli.print_version',
+            'clu.repl.columnize',
             'clu.sanitizer',
+            'clu.scripts',
+            'clu.scripts.ansicolors',
+            'clu.scripts.forkumask',
             'clu.testing',
             'clu.testing.utils',
             'clu.typespace',
