@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
+from importlib.machinery import all_suffixes
 
 import abc
+import itertools
 import sys, os
 import warnings
 import weakref
@@ -189,6 +191,19 @@ def determine_name(thing, name=None, try_repr=False):
     # up returning None:
     return search_for_name(thing)
 
+# N.B. Items in the “replaceable_endings” tuple that
+# possibly contain other such items should appear
+# *before* the items that they contain, e.g.:
+ending_prefixes = tuple(f"{os.extsep}{name}" \
+                                  for name \
+                                   in pytuple('init', 'main'))
+ending_suffixes = tuple(all_suffixes())
+replaceable_endings  = tuple(f"{pre}{suf}" \
+                            for pre, suf \
+                             in itertools.product(ending_prefixes,
+                                                  ending_suffixes))
+replaceable_endings += ending_suffixes
+
 def path_to_dotpath(path, relative_to=None):
     """ Convert a file path (e.g. “/yo/dogg/iheard/youlike.py”)
         to a dotpath (á la “yo.dogg.iheard.youlike”) in what I
@@ -212,12 +227,7 @@ def path_to_dotpath(path, relative_to=None):
     dotpath = relpath.replace(os.path.sep, QUALIFIER)
     
     # Trim off any remaining “.py” suffixes,
-    # and extraneous dot-prefixes –
-    # N.B. Items in “replaceable_endings” tuple that
-    # possibly contain other such items should appear
-    # *before* the items that they contain, e.g.:
-    replaceable_endings = ('.__init__.py', '.py')
-    
+    # and extraneous dot-prefixes:
     for ending in replaceable_endings:
         if dotpath.endswith(ending):
             dotpath = dotpath[:len(dotpath)-len(ending)]
@@ -229,7 +239,7 @@ def path_to_dotpath(path, relative_to=None):
     # should contain dashes:
     if '-' in dotpath:
         warnings.warn(f"Dotpath contains dashes: “{dotpath}”",
-                      BadDotpathWarning, stacklevel=2)
+                        BadDotpathWarning, stacklevel=2)
     
     return dotpath
 
@@ -268,6 +278,9 @@ class ValueDescriptor(object):
     def __get__(self, *args):
         return self.value
     
+    def __set__(self, instance, value):
+        pass
+    
     def __repr__(self):
         from clu.constants.consts import ENCODING
         return isinstance(self.value, str)   and self.value or \
@@ -317,7 +330,7 @@ class Registry(abc.ABC, metaclass=Slotted):
         else:
             appname = determine_name(cls)
         if appname in classes:
-            raise ValueError(f"appname already registered: {appname}")
+            raise TypeError(f"appname already registered: {appname}")
         classes[appname] = cls
         super(Registry, cls).__init_subclass__(**kwargs)
         cls.instances = weakref.WeakValueDictionary()
@@ -397,8 +410,7 @@ class ExporterBase(MutableMapping, Registry, metaclass=Prefix):
         
         instance.__exports__ = {}
         instance.path = path
-        instance.dotpath = path_to_dotpath(instance.path,
-                                           relative_to=cls.prefix)
+        instance.dotpath = path_to_dotpath(path, relative_to=cls.prefix)
         
         if instance.dotpath is not None:
             cls.instances[instance.dotpath] = instance
@@ -421,6 +433,8 @@ class ExporterBase(MutableMapping, Registry, metaclass=Prefix):
         # “typing” shit and I am not interested at this time, and
         # b) it’s too useful a method to give it all up. So deal.
         from clu.typology import isstring
+        if not key:
+            raise ValueError("instance key required")
         if not isstring(key):
             raise TypeError("instance registry access by string keys only")
         return cls.instances[key]
@@ -490,6 +504,10 @@ class ExporterBase(MutableMapping, Registry, metaclass=Prefix):
         """ Get a value view on the exported items dictionary. """
         return self.__exports__.values()
     
+    def items(self):
+        """ Get a item view on the exported items dictionary. """
+        return self.__exports__.items()
+    
     def get(self, key, default=NoDefault):
         """ Get and return a value for a key, with an optional default """
         if default is NoDefault:
@@ -606,15 +624,15 @@ class ExporterBase(MutableMapping, Registry, metaclass=Prefix):
         """
         return self.export
     
-    def all_tuple(self):
+    def all_tuple(self, *additionals):
         """ For use in module `__all__` tuple definitions """
-        return tuple(self.keys())
+        return tuple(self.keys()) + tuple(additionals)
     
-    def dir_function(self):
+    def dir_function(self, *additionals):
         """ Return a list containing the exported module names. """
-        return lambda: list(self.keys())
+        return lambda: list(tuple(self.keys()) + tuple(additionals))
     
-    def all_and_dir(self):
+    def all_and_dir(self, *additionals):
         """ Assign a modules’ __all__ and __dir__ values, e.g.:
             
                 __all__, __dir__ = exporter.all_and_dir()
@@ -623,9 +641,10 @@ class ExporterBase(MutableMapping, Registry, metaclass=Prefix):
             all calls to `exporter.export(…)` (aka @export) have
             been made – q.v. the “decorator()” method supra.
         """
-        return self.all_tuple(), self.dir_function()
+        return self.all_tuple(*additionals), \
+               self.dir_function(*additionals)
     
-    def dir_and_all(self):
+    def dir_and_all(self, *additionals):
         """ Assign a modules’ __dir__ and __all__ values, e.g.:
             
                 __dir__, __all__ = exporter.dir_and_all()
@@ -634,7 +653,8 @@ class ExporterBase(MutableMapping, Registry, metaclass=Prefix):
             all calls to `exporter.export(…)` (aka @export) have
             been made – q.v. the “decorator()” method supra.
         """
-        return self.dir_function(), self.all_tuple() # OPPOSITE!
+        return self.dir_function(*additionals), \
+               self.all_tuple(*additionals) # OPPOSITE!
     
     @staticmethod
     def cache_info():
@@ -726,7 +746,7 @@ class Exporter(ExporterBase, prefix=BASEPATH, appname=PROJECT_NAME):
         or you risk UNDEFINED BEHAVIOR!!!! Erm.
         
         Also note that all derived subclasses of ExporterBase will
-        automatrically be slotted classes – a “__slots__” attribute
+        automatically be slotted classes – a “__slots__” attribute
         will be added to the class dict by the “clu.exporting.Slotted”
         metaclass, if your subclass doesn’t define one – and so if
         you desire a class with a working “__dict__” attribute for
