@@ -1,16 +1,19 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
+from inspect import getattr_static
 from itertools import chain
 from functools import partial, wraps
 
+iterchain = chain.from_iterable
+
 from clu.constants.consts import λ, φ, pytuple, QUALIFIER
-from clu.enums import alias
 from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
 # PREDICATE LOGIC: negate(function) will “negate” a boolean predicate function –
+
 assigned = pytuple('doc', 'annotations')
 wrap = lambda function: wraps(function, assigned=assigned)
 
@@ -74,19 +77,17 @@ isiterable = lambda thing: anypyattrs(thing, 'iter', 'getitem')
 # q.v. `merge_two(…)` implementation sub.
 ismergeable = lambda thing: bool(hasattr(thing, 'get') and isiterable(thing))
 
-# ACCESSORS: getattr(…) shortcuts:
+# ACCESSORS: getattr(…) shortcuts
 
 always = lambda thing: True
 never = lambda thing: False
 nuhuh = lambda thing: None
 
-no_op     = lambda thing, atx, default=None: thing
+no_op     = lambda thing, atx=None, default=None: thing
 or_none   = lambda thing, atx: getattr(thing, atx, None)
+stor_none = lambda thing, atx: getattr_static(thing, atx, None)
 getpyattr = lambda thing, atx, default=None: getattr(thing, f'__{atx}__', default)
-
-getitem   = lambda thing, itx, default=None: thing.__contains__(itx) \
-                                         and thing.__getitem__(itx) \
-                                          or default
+getitem   = lambda thing, itx, default=None: itx in thing and thing[itx] or default
 
 @export
 def resolve(thing, atx):
@@ -100,6 +101,18 @@ def resolve(thing, atx):
         thing = or_none(thing, atn)
     return thing
 
+@export
+def stresolve(thing, atx):
+    """ stresolve(thing, atx) → statically retrieve and resolve an attribute,
+        following each dotted segment, back from its host thing.
+        
+        Q.v. the standard library “operator” module notes supra.:
+            https://docs.python.org/3/library/operator.html#operator.attrgetter
+    """
+    for atn in atx.split(QUALIFIER):
+        thing = stor_none(thing, atn)
+    return thing
+
 accessor = lambda function, thing, *attrs, default=None: ([atx for atx in (function(thing, atx) \
                                                                for atx in attrs) \
                                                                 if atx is not None] or [default]).pop(0)
@@ -117,18 +130,22 @@ collator = lambda function, xatx, *things, default=tuple(): tuple(atx for atx in
                                                                        if atx is not None) or default
 
 attr     = lambda thing, *attrs, default=None: accessor(resolve,   thing, *attrs, default=default)
+stattr   = lambda thing, *attrs, default=None: accessor(stresolve, thing, *attrs, default=default)
 pyattr   = lambda thing, *attrs, default=None: accessor(getpyattr, thing, *attrs, default=default)
 item     = lambda thing, *items, default=None: accessor(getitem,   thing, *items, default=default)
 
 attrs    = lambda thing, *attrs, default=tuple(): acquirer(resolve,   thing, *attrs, default=default)
+stattrs  = lambda thing, *attrs, default=tuple(): acquirer(stresolve, thing, *attrs, default=default)
 pyattrs  = lambda thing, *attrs, default=tuple(): acquirer(getpyattr, thing, *attrs, default=default)
 items    = lambda thing, *items, default=tuple(): acquirer(getitem,   thing, *items, default=default)
 
 attr_search   = lambda atx, *things, default=None: searcher(resolve,   atx, *things, default=default)
+stattr_search = lambda atx, *things, default=None: searcher(stresolve, atx, *things, default=default)
 pyattr_search = lambda atx, *things, default=None: searcher(getpyattr, atx, *things, default=default)
 item_search   = lambda itx, *things, default=None: searcher(getitem,   itx, *things, default=default)
 
 attr_across   = lambda atx, *things, default=tuple(): collator(resolve,   atx, *things, default=default)
+stattr_across = lambda atx, *things, default=tuple(): collator(stresolve, atx, *things, default=default)
 pyattr_across = lambda atx, *things, default=tuple(): collator(getpyattr, atx, *things, default=default)
 item_across   = lambda itx, *things, default=tuple(): collator(getitem,   itx, *things, default=default)
 
@@ -150,10 +167,6 @@ def enumchoices(cls):
         return tuple()
     return tuple(choice.name for choice in cls)
 
-isaliasdescriptor = lambda thing: isinstance(thing, alias)
-hasmembers = lambda thing: isenum(thing) and haspyattr(thing, 'members')
-hasaliases = lambda thing: isenum(thing) and haspyattr(thing, 'aliases')
-
 # PREDICATE LOGCIAL FUNCTIONS: all/any/and/or/xor shortcuts:
 
 predicate_nop = lambda *things: None
@@ -260,16 +273,6 @@ isslotted = lambda thing: haspyattr(thing, 'slots') and negate(isclasstype)(thin
 isdictish = lambda thing: haspyattr(thing, 'dict') and negate(isclasstype)(thing)
 isslotdicty = lambda thing: allpyattrs(thing, 'slots', 'dict') and negate(isclasstype)(thing)
 
-@export
-def slots_for(cls):
-    """ slots_for(cls) → get the summation of the `__slots__` tuples for a class and its ancestors """
-    # q.v. https://stackoverflow.com/a/6720815/298171
-    if not isclasstype(cls):
-        return tuple()
-    return tuple(chain.from_iterable(
-                 getpyattr(ancestor, 'slots', tuple()) \
-                       for ancestor in cls.__mro__))
-
 # For sorting with ALL_CAPS stuff first or last:
 case_sort = lambda c: c.lower() if c.isupper() else c.upper()
 
@@ -307,6 +310,17 @@ def noneof(*items):
     """ noneof(*items) → Return the result of “not any(…)” on all non-`None` arguments """
     return negate(any)(item for item in items if item is not None)
 
+@export
+def slots_for(cls):
+    """ slots_for(cls) → get the summation of the `__slots__` tuples for a class and its ancestors """
+    # q.v. https://stackoverflow.com/a/6720815/298171
+    if not isclasstype(cls):
+        return slots_for(type(cls))
+    mro = pyattr(cls, 'mro', 'bases', default=tuplize(object))
+    return tuple(iterchain(
+                 getpyattr(ancestor, 'slots', tuple()) \
+                       for ancestor in reversed(mro)))
+
 # MODULE EXPORTS:
 export(negate,          name='negate',          doc="negate(function) → Negate a boolean function, returning the callable inverse. \n" + negate_doc)
 
@@ -335,31 +349,35 @@ export(never,           name='never',           doc="never(thing) → boolean pr
 export(nuhuh,           name='nuhuh',           doc="nuhuh(thing) → boolean predicate that always returns `None`")
 export(no_op,           name='no_op',           doc="no_op(thing, attribute[, default]) → shortcut for `(attribute or default)`")
 export(or_none,         name='or_none',         doc="or_none(thing, attribute) → shortcut for `getattr(thing, attribute, None)`")
+export(stor_none,       name='stor_none',       doc="stor_none(thing, attribute) → shortcut for `inspect.getattr_static(thing, attribute, None)`")
 export(getpyattr,       name='getpyattr',       doc="getpyattr(thing, attribute[, default]) → shortcut for `getattr(thing, '__%s__' % attribute[, default])`")
 export(getitem,         name='getitem',         doc="getitem(thing, item[, default]) → shortcut for `thing.get(item[, default])`")
+
 export(accessor,        name='accessor',        doc="accessor(func, thing, *attributes) → return the first non-None value had by successively applying func(thing, attribute) to all attributes")
 export(acquirer,        name='acquirer',        doc="acquirer(func, thing, *attributes) → return all of the non-None values had by successively applying func(thing, attribute) to all attributes")
 export(searcher,        name='searcher',        doc="searcher(func, attribute, *things) → return the first non-None value had by successively applying func(thing, attribute) sequentially to all things")
 export(collator,        name='collator',        doc="collator(func, attribute, *things) → return all of the non-None values had by successively applying func(thing, attribute) across all things")
 
 export(attr,            name='attr',            doc="attr(thing, *attributes) → Return the first existing attribute from `thing`, given 1+ attribute names")
+export(stattr,          name='stattr',          doc="stattr(thing, *attributes) → Statically return the first existing attribute from `thing`, given 1+ attribute names (q.v. “inspect.getattr_static(¬)” supra.)")
 export(pyattr,          name='pyattr',          doc="pyattr(thing, *attributes) → Return the first existing __special__ attribute from `thing`, given 1+ attribute names")
 export(item,            name='item',            doc="item(thing, *itemnames) → Return the first existing item held by `thing`, given 1+ item names")
+
 export(attrs,           name='attrs',           doc="attrs(thing, *attributes) → Return all of the existing named attributes from `thing`, given 1+ attribute names")
+export(stattrs,         name='stattrs',         doc="stattrs(thing, *attributes) → Statically return all of the existing named attributes from `thing`, given 1+ attribute names (q.v. “inspect.getattr_static(¬)” supra.)")
 export(pyattrs,         name='pyattrs',         doc="pyattrs(thing, *attributes) → Return all of the existing named __special__ attributes from `thing`, given 1+ attribute names")
 export(items,           name='items',           doc="items(thing, *itemnames) → Return all of the existing named items held by `thing`, given 1+ item names")
+
 export(attr_search,     name='attr_search',     doc="attr_search(attribute, *things) → Return the first-found existing attribute from a thing, given 1+ things")
+export(stattr_search,   name='stattr_search',   doc="stattr_search(attribute, *things) → Statically return the first-found existing attribute from a thing, given 1+ things (q.v. “inspect.getattr_static(¬)” supra.)")
 export(pyattr_search,   name='pyattr_search',   doc="pyattr_search(attribute, *things) → Return the first-found existing __special__ attribute from a thing, given 1+ things")
 export(item_search,     name='item_search',     doc="item_search(itemname, *things) → Return the first-found existing item from a thing, given 1+ things")
+
 export(attr_across,     name='attr_across',     doc="attr_across(attribute, *things) → Return all of the existing named attributes across all things (given 1+ things)")
+export(stattr_across,   name='stattr_across',   doc="stattr_across(attribute, *things) → Statically return all of the existing named attributes across all things (given 1+ things) (q.v. “inspect.getattr_static(¬)” supra.)")
 export(pyattr_across,   name='pyattr_across',   doc="pyattr_across(attribute, *things) → Return all of the existing named __special__ attributes across all things (given 1+ things)")
 export(item_across,     name='item_across',     doc="item_across(attribute, *things) → Return all of the existing named items held across all things (given 1+ things)")
 
-export(isaliasdescriptor,                       name='isaliasdescriptor',
-                                                doc="isaliasdescriptor(thing) → boolean predicate, returns True if `thing` is an aliasing descriptor bound to an existing Enum member")
-export(hasmembers,      name='hasmembers',      doc="hasmembers(cls) → boolean predicate, True if `cls` descends from Enum and has 1+ items in its `__members__` dict")
-export(hasaliases,      name='hasaliases',      doc="hasaliases(cls) → boolean predicate, True if `cls` descends from Enum and has 1+ items in its `__aliases__` dict")
-
 export(predicate_nop,   name='predicate_nop',   doc="predicate_nop(thing) → boolean predicate that always returns `None`")
 export(function_nop,    name='function_nop',    doc="function_nop(*args) → variadic function always returns `None`")
 export(uncallable,      name='uncallable',      doc="uncallable(thing) → boolean predicate, shortcut for `not callable(thing)`")
